@@ -13,11 +13,11 @@ use Log::Any qw($log);
 
 =head1 VERSION
 
-Version v0.8.6
+Version v0.8.7
 
 =cut
 
-our $VERSION = 'v0.8.6';
+our $VERSION = 'v0.8.7';
 
 =head1 SYNOPSIS
 
@@ -214,7 +214,8 @@ sub _get {
 
     $self->log( sprintf "METHOD GET, URL: %s\n", $url );
 
-    my HTTP::Response $response = $self->ua->get($url);
+    #@type HTTP::Response
+    my $response = $self->ua->get($url);
 
     return $self->_parse( $response->is_success ? decode_json $response->decoded_content : undef );
 }
@@ -234,7 +235,8 @@ sub _post {
 
     $self->log( sprintf "METHOD POST, URL %s, %s\n", $url, Dumper \%passed_params );
 
-    my HTTP::Response $response = $self->ua->post( $url, \%passed_params );
+    #@type HTTP::Response
+    my $response = $self->ua->post( $url, \%passed_params );
 
     return $self->_parse( $response->is_success ? decode_json $response->decoded_content : undef );
 }
@@ -285,7 +287,7 @@ sub _parse {
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<cynovg at cpan.org>, or through the web interface at L<https://github.com/cynovg/WG-API/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to C<cynovg at cpan.org>, or through the web interface at L<https://gitlab.com/cynovg/WG-API/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
 
@@ -299,7 +301,7 @@ You can also look for information at:
 
 =item * RT: GitHub's request tracker (report bugs here)
 
-L<https://github.com/cynovg/WG-API/issues>
+L<https://gitlab.com/cynovg/WG-API/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
