@@ -10,11 +10,11 @@ WG::API::WoWp - Modules to work with Wargaming.net Public API for World of Warpl
 
 =head1 VERSION
 
-Version v0.8.6
+Version v0.8.7
 
 =cut
 
-our $VERSION = 'v0.8.6';
+our $VERSION = 'v0.8.7';
 
 use constant api_uri => 'api.worldofwarplanes.ru/wowp';
 
@@ -82,7 +82,7 @@ Method returns details on player's aircrafts.
 sub account_planes {
     my $self = shift;
 
-    return $self->_request( 'get', 'account/planes', [ 'language', 'fields', 'access_token', 'account_id' ],
+    return $self->_request( 'get', 'account/planes', [ 'language', 'fields', 'access_token', 'account_id', 'in_garage', 'plane_id' ],
         ['account_id'], @_ );
 }
 
@@ -143,7 +143,7 @@ sub ratings_top {
 
     return $self->_request(
         'get', 'ratings/top',
-        [ 'language', 'fields', 'type', 'date', 'rank_field', 'limit' ],
+        [ 'language', 'fields', 'type', 'date', 'rank_field', 'limit', 'page_no' ],
         [ 'type',     'rank_field' ], @_
     );
 }
@@ -162,7 +162,7 @@ sub ratings_dates {
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<cynovg at cpan.org>, or through the web interface at L<https://github.com/cynovg/WG-API/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to C<cynovg at cpan.org>, or through the web interface at L<https://gitlab.com/cynovg/WG-API/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
 
@@ -176,7 +176,7 @@ You can also look for information at:
 
 =item * RT: GitHub's request tracker (report bugs here)
 
-L<https://github.com/cynovg/WG-API/issues>
+L<https://gitlab.com/cynovg/WG-API/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
