@@ -10,11 +10,11 @@ WG::API::WoWs - Moduled for work with Wargaming.net Public API for Worlf of Wars
 
 =head1 VERSION
 
-Version v0.8.6
+Version v0.8.7
 
 =cut
 
-our $VERSION = 'v0.8.6';
+our $VERSION = 'v0.8.7';
 
 use constant api_uri => 'api.worldofwarships.ru/wows';
 
@@ -81,7 +81,20 @@ Method returns information about players' achievements. Accounts with hidden gam
 sub account_achievements {
     my $self = shift;
 
-    return $self->_request( 'get', 'account/achievements', [ 'language', 'fields', 'account_id' ], ['account_id'], @_ );
+    return $self->_request( 'get', 'account/achievements', [ 'language', 'fields', 'account_id', 'access_token' ], ['account_id'], @_ );
+}
+
+=head3 B<account_statsbydate( [ %params ] )>
+
+Method returns statistics slices by dates in specified time span.
+
+=cut
+
+sub account_statsbydate {
+    my $self = shift;
+
+    return $self->_request( 'get', 'account/statsbydate', [ 'language', 'fields', 'dates', 'access_token', 'extra', 'account_id' ],
+        ['account_id'], @_ );
 }
 
 =head2 Warships
@@ -102,7 +115,7 @@ sub ships_stats {
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<cynovg at cpan.org>, or through the web interface at L<https://github.com/cynovg/WG-API/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to C<cynovg at cpan.org>, or through the web interface at L<https://gitlab.com/cynovg/WG-API/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
 
@@ -116,7 +129,7 @@ You can also look for information at:
 
 =item * RT: GitHub's request tracker (report bugs here)
 
-L<https://github.com/cynovg/WG-API/issues>
+L<https://gitlab.com/cynovg/WG-API/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
